/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <app.h>
#include <Elementary.h>
#include <viewmgr.h>
#include <app_debug.h>
#include <app_define.h>
#include <efl_util.h>

#include "define.h"
#include "view.h"

SET_TAG(PACKAGE)

struct _appdata {
	const char *name;
	Evas_Object *win;
};

static Evas_Object *_add_win(const char *name)
{
	Evas_Object *win;

	win = elm_win_add(NULL, name, ELM_WIN_BASIC);
	if (!win) {
		_ERR("elm_win_add failed");
		return NULL;
	}
	elm_win_title_set(win, PACKAGE);
	elm_win_focus_highlight_enabled_set(win, EINA_FALSE);
	elm_win_focus_highlight_style_set(win, "invisible");
	efl_util_set_window_opaque_state(win, 1);

	evas_object_show(win);

	return win;
}

static bool _create(void *data)
{
	struct _appdata *ad;
	Evas_Object *win;

	if (!data) {
		_ERR("failed to get data");
		return false;
	}

	ad = data;

	elm_app_base_scale_set(APP_BASE_SCALE);

	win = _add_win(ad->name);
	if (!win) {
		_ERR("failed to create win object");
		return false;
	}

	if (!viewmgr_create(win)) {
		_ERR("failed to initialize viewmgr");
		evas_object_del(win);
		return false;
	}

	viewmgr_add_view(view_bgimage_get_vclass(), NULL);
	ad->win = win;

	viewmgr_show_view(VIEW_BGIMAGE);

	return true;
}

static void _terminate(void *data)
{
	struct _appdata *ad;

	if (!data) {
		_ERR("failed to get data");
		return;
	}

	ad = data;

	if (ad->win) {
		viewmgr_remove_view(VIEW_BGIMAGE);
		evas_object_del(ad->win);
		ad->win = NULL;
	}
}

int main(int argc, char *argv[])
{
	struct _appdata ad;
	ui_app_lifecycle_callback_s cbs = {
		.create = _create,
		.terminate = _terminate,
	};

	memset(&ad, 0x00, sizeof(ad));
	ad.name = PACKAGE;

	return ui_app_main(argc, argv, &cbs, &ad);
}
